@@ -1,4 +1,3 @@
-import json
 from .base import Resource
 
 
@@ -11,11 +10,14 @@ class Domains(Resource):
 
     def get_available_domains(self, **kwargs):
         """
-            Get all domains available within your account
-            :param childAccountId:  The child account to narrow results
-            :return:  'list' object
-            """
-        endpoint = "/available"  # e.g. "/sendingIps"
+        Get all domains available within your account
+
+        :param int childAccountId:  The child account to narrow results
+
+        :return:  A ``list`` object of ``dict`` containing details of the domains available.
+        """
+
+        endpoint = "/available"
         apiUrl = self.uri + endpoint
         parameters = self.SetParameters(kwargs, self.param_model)
         apiResponse = self.request("GET", apiUrl, params=parameters)
