@@ -1,4 +1,3 @@
-import json
 from .base import Resource
 
 
@@ -11,9 +10,13 @@ class Regions(Resource):
     def get_regions(self):
         """
         Gets current list of regions supported by the system.
-        :return: 'list' object
+
+        :return: A ``list`` object of available regions as ``str``.  See
+            `Current Regions <https://inboxtracker.readthedocs.io/en/latest/resources/regions.html#supported-regions>`_
+            for an updated list of supported regions.
         """
-        endpoint = ""  # e.g. "/sendingIps"
+
+        endpoint = ""
         apiUrl = self.uri + endpoint
         parameters = self.SetParameters({}, self.param_model)
         apiResponse = self.request("GET", apiUrl, params=parameters)
